@@ -17,7 +17,11 @@ from .ankiconnect_gateway import (
 class MockNoteInfo(NoteInfo):
     noteId: int = 1
     tags: Sequence[str] = ["MockTag"]
-    fields: Mapping[str, AnkiField] = {"Text": AnkiField(value="MockText", order=0)}
+    fields: Mapping[str, AnkiField] = {
+        "Text": AnkiField(value="MockText", order=0),
+        "raw_question": AnkiField(value="MockQuestion", order=1),
+        "raw_answer": AnkiField(value="MockAnswer", order=2),
+    }
     modelName: str = "MockModel"
     cards: Sequence[int] = [1]
 
@@ -58,7 +62,7 @@ class TestAnkiConnectGateway:
         tmp_read_dir = get_host_home_dir() / "ankidecks"
         gateway = AnkiConnectGateway(
             ankiconnect_url=ANKICONNECT_URL,
-            base_deck="Test deck",
+            root_deck="Test deck",
             tmp_read_dir=tmp_read_dir,
             tmp_write_dir=self.output_path,
             max_deletions_per_run=1,
@@ -83,7 +87,7 @@ class TestAnkiConnectGateway:
     def test_error_if_deleting_more_than_allowed(self):
         gateway = AnkiConnectGateway(
             ankiconnect_url=ANKICONNECT_URL,
-            base_deck="Test deck",
+            root_deck="Test deck",
             tmp_read_dir=Path("/tmp"),
             tmp_write_dir=Path("/tmp"),
             max_deletions_per_run=0,
@@ -97,7 +101,7 @@ def test_error_if_not_running():
     with pytest.raises(ConnectionError, match="Could not connect to Anki"):
         AnkiConnectGateway(
             ankiconnect_url="http://localhost:1234",
-            base_deck="Test deck",
+            root_deck="Test deck",
             tmp_read_dir=Path("/tmp"),
             tmp_write_dir=Path("/tmp"),
             max_deletions_per_run=0,
