@@ -1,10 +1,10 @@
 from collections.abc import Sequence
 from typing import Protocol
 
+from memium.source.prompt import QAWithDoc
+
 from ..document import Document
-from ..prompts.prompt import BasePrompt
 
 
 class BasePromptExtractor(Protocol):
-    def extract_prompts(self, document: Document) -> Sequence[BasePrompt]:
-        ...
+    def extract_prompts(self, document: Document) -> Sequence[QAWithDoc]: ...
